# urtools

Custom functions and other utilities that I find useful and use across many projects. Not all of them were created by me. Pieces of code borrowed from various people across the internet are annotated with a comment `# source: <URL>`.

## Install

Requires Python >= 3.8

```sh
python -m pip install urtools
```

## TODO

## Functionalities

- [ ] `alt`

### Repo

- [ ] Documentation